@@ -1,9 +1,9 @@
-# $Id: mvnorm.R 187 2008-07-02 12:02:34Z thothorn $
+# $Id: mvnorm.R 188 2008-07-08 07:33:41Z thothorn $
 
 rmvnorm<-function (n, mean = rep(0, nrow(sigma)), sigma = diag(length(mean)),
                    method=c("eigen", "svd", "chol"))
 {    
-    if (!isSymmetric(sigma)) {
+    if (!isSymmetric(sigma, tol = sqrt(.Machine$double.eps))) {
         stop("sigma must be a symmetric matrix")
     }
     if (length(mean) != nrow(sigma)) {
@@ -57,7 +57,7 @@ dmvnorm <- function (x, mean, sigma, log=FALSE)
     if (NCOL(x) != NCOL(sigma)) {
         stop("x and sigma have non-conforming size")
     }
-    if (!isSymmetric(sigma)) {
+    if (!isSymmetric(sigma, tol = sqrt(.Machine$double.eps))) {
         stop("sigma must be a symmetric matrix")
     }
     if (length(mean) != NROW(sigma)) {
